==> haskell-ixset-typed-0.3.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ixset-typed.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ixset-typed
version: 0.3.1
id: ixset-typed-0.3.1-3enAfzK2vSn3UjLhkzNdBn
key: ixset-typed-0.3.1-3enAfzK2vSn3UjLhkzNdBn
license: BSD3
maintainer: Andres Löh <andres@well-typed.com>
synopsis: Efficient relational queries on Haskell sets.
description:
    This Haskell package provides a data structure of sets that are indexed
    by potentially multiple indices.
    .
    Sets can be created, modified, and queried in various ways.
    .
    The package is a variant of the <https://hackage.haskell.org/package/ixset ixset>
    package. The ixset package makes use
    of run-time type information to find a suitable index on a query, resulting
    in possible run-time errors when no suitable index exists. In ixset-typed,
    the types of all indices available or tracked in the type system.
    Thus, ixset-typed should be safer to use than ixset, but in turn requires
    more GHC extensions.
    .
    At the moment, the two packages are relatively compatible. As a consequence
    of the more precise types, a few manual tweaks are necessary when switching
    from one to the other, but the interface is mostly the same.
category: Data Structures
author: Andres Löh, Happstack team, HAppS LLC
exposed: True
exposed-modules:
    Data.IxSet.Typed Data.IxSet.Typed.Ix
abi: 499f603386da1d26eb2d41f6fac8beea
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/ixset-typed-0.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/ixset-typed-0.3.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/ixset-typed-0.3.1
hs-libraries: HSixset-typed-0.3.1-3enAfzK2vSn3UjLhkzNdBn
depends:
    base-4.9.0.0 containers-0.5.7.1 deepseq-1.4.2.0
    safecopy-0.9.3.1-3kmdSnd9TxSGD9A8MvyrZm
    syb-0.6-C65vWCsht6A8uLstpQIXyj template-haskell-2.11.0.0
haddock-interfaces: /usr/share/doc/haskell-ixset-typed/html/ixset-typed.haddock
haddock-html: /usr/share/doc/haskell-ixset-typed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ixset-typed-0.3.1-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ixset-typed.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ixset-typed
version: 0.3.1
id: ixset-typed-0.3.1-6zK9t8RjqFH35iu2OQCJSZ
key: ixset-typed-0.3.1-6zK9t8RjqFH35iu2OQCJSZ
license: BSD3
maintainer: Andres Löh <andres@well-typed.com>
synopsis: Efficient relational queries on Haskell sets.
description:
    This Haskell package provides a data structure of sets that are indexed
    by potentially multiple indices.
    .
    Sets can be created, modified, and queried in various ways.
    .
    The package is a variant of the <https://hackage.haskell.org/package/ixset ixset>
    package. The ixset package makes use
    of run-time type information to find a suitable index on a query, resulting
    in possible run-time errors when no suitable index exists. In ixset-typed,
    the types of all indices available or tracked in the type system.
    Thus, ixset-typed should be safer to use than ixset, but in turn requires
    more GHC extensions.
    .
    At the moment, the two packages are relatively compatible. As a consequence
    of the more precise types, a few manual tweaks are necessary when switching
    from one to the other, but the interface is mostly the same.
category: Data Structures
author: Andres Löh, Happstack team, HAppS LLC
exposed: True
exposed-modules:
    Data.IxSet.Typed Data.IxSet.Typed.Ix
abi: 04471307b4e38058e244d41e2bf775b8
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/ixset-typed-0.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/ixset-typed-0.3.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/ixset-typed-0.3.1
hs-libraries: HSixset-typed-0.3.1-6zK9t8RjqFH35iu2OQCJSZ
depends:
    base-4.9.0.0 containers-0.5.7.1 deepseq-1.4.2.0
    safecopy-0.9.3.2-B5OC2BqilkMJcc92Mn3vFX
    syb-0.6-C65vWCsht6A8uLstpQIXyj template-haskell-2.11.0.0
haddock-interfaces: /usr/share/doc/haskell-ixset-typed/html/ixset-typed.haddock
haddock-html: /usr/share/doc/haskell-ixset-typed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
